@@ -10,5 +10,6 @@ function(data, parms, n.used, m, link="logit")
     p <- drop(linkinvfun(X %*% parms))
     id1 <- sample.int(n.sites, n.used, replace = TRUE, prob = p)
     id2 <- sample.int(n.sites, n.avail, replace = TRUE)
-    data.frame(status=c(rep(1, n.used), rep(0, n.avail)), data[c(id1, id2),])
+    data.frame(status=c(rep(1, n.used), rep(0, n.avail)), 
+        data[c(id1, id2),,drop=FALSE])
 }
